var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database =
[
    [ "com::sun::star::text::DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html#ad9e399bc7074c22e5069ac12b2162aa1", null ],
    [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "DataBaseFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html#a099663d4d0376877390c8432aed14b2c", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ]
];